@@ -2,15 +2,17 @@
 
 test_that("Column names are renamed correctly", {
   suppressMessages(expect_true(names(mark_duration(qualtrics_fetch))[1] ==
-                                 "StartDate"))
+    "StartDate"))
   suppressMessages(expect_true(names(mark_duration(qualtrics_fetch,
-                                                   rename = FALSE))[1] ==
-                                 "StartDate"))
+    rename = FALSE
+  ))[1] ==
+    "StartDate"))
   suppressMessages(expect_true(names(mark_duration(qualtrics_numeric))[1] ==
-                                 "StartDate"))
+    "StartDate"))
   suppressMessages(expect_true(names(mark_duration(qualtrics_numeric,
-                                                   rename = FALSE))[1] ==
-                                 "StartDate"))
+    rename = FALSE
+  ))[1] ==
+    "StartDate"))
   suppressMessages(expect_message(mark_duration(qualtrics_numeric)))
 })
 
@@ -25,18 +27,20 @@ test_that("Mark messages are displayed properly", {
   suppressMessages(expect_message(mark_duration(qualtrics_numeric)))
   suppressMessages(expect_message(
     mark_duration(qualtrics_numeric, min_duration = 10, quiet = FALSE),
-    "took less time"))
+    "took less time"
+  ))
   suppressMessages(expect_message(
     mark_duration(qualtrics_numeric, max_duration = 200, quiet = FALSE),
-    "took more time"))
+    "took more time"
+  ))
   expect_message(mark_duration(qualtrics_numeric, quiet = TRUE), NA)
 })
 
 test_that("Mark output is printed properly", {
   expect_visible(mark_duration(qualtrics_numeric, quiet = TRUE))
   expect_invisible(
-    mark_duration(qualtrics_numeric, quiet = TRUE, print = FALSE
-    ))
+    mark_duration(qualtrics_numeric, quiet = TRUE, print = FALSE)
+  )
 })
 
 test_that("Marks create data frames of correct size", {
@@ -64,15 +68,17 @@ test_that("Marks create data frames of correct size", {
 
 test_that("Column names are renamed correctly", {
   suppressMessages(expect_true(names(check_duration(qualtrics_fetch))[1] ==
-                                 "StartDate"))
+    "StartDate"))
   suppressMessages(expect_true(names(check_duration(qualtrics_fetch,
-                                                    rename = FALSE))[1] ==
-                                 "StartDate"))
+    rename = FALSE
+  ))[1] ==
+    "StartDate"))
   suppressMessages(expect_true(names(check_duration(qualtrics_numeric))[1] ==
-                                 "StartDate"))
+    "StartDate"))
   suppressMessages(expect_true(names(check_duration(qualtrics_numeric,
-                                                    rename = FALSE))[1] ==
-                                 "StartDate"))
+    rename = FALSE
+  ))[1] ==
+    "StartDate"))
   suppressMessages(expect_message(check_duration(qualtrics_numeric)))
 })
 
@@ -87,18 +93,20 @@ test_that("Check messages are displayed properly", {
   suppressMessages(expect_message(check_duration(qualtrics_numeric)))
   suppressMessages(expect_message(
     check_duration(qualtrics_numeric, min_duration = 10, quiet = FALSE),
-    "took less time"))
+    "took less time"
+  ))
   suppressMessages(expect_message(
     check_duration(qualtrics_numeric, max_duration = 200, quiet = FALSE),
-    "took more time"))
+    "took more time"
+  ))
   expect_message(check_duration(qualtrics_numeric, quiet = TRUE), NA)
 })
 
 test_that("Check output is printed properly", {
   expect_visible(check_duration(qualtrics_numeric, quiet = TRUE))
   expect_invisible(
-    check_duration(qualtrics_numeric, quiet = TRUE, print = FALSE
-    ))
+    check_duration(qualtrics_numeric, quiet = TRUE, print = FALSE)
+  )
 })
 
 test_that("Checks create data frames of correct size", {
@@ -139,15 +147,17 @@ test_that("Exclusion column moved to first column when keep = TRUE", {
 
 test_that("Column names are renamed correctly", {
   suppressMessages(expect_true(names(exclude_duration(qualtrics_fetch))[1] ==
-                                 "StartDate"))
+    "StartDate"))
   suppressMessages(expect_true(names(exclude_duration(qualtrics_fetch,
-                                                      rename = FALSE))[1] ==
-                                 "StartDate"))
+    rename = FALSE
+  ))[1] ==
+    "StartDate"))
   suppressMessages(expect_true(names(exclude_duration(qualtrics_numeric))[1] ==
-                                 "StartDate"))
+    "StartDate"))
   suppressMessages(expect_true(names(exclude_duration(qualtrics_numeric,
-                                                      rename = FALSE))[1] ==
-                                 "StartDate"))
+    rename = FALSE
+  ))[1] ==
+    "StartDate"))
   suppressMessages(expect_message(exclude_duration(qualtrics_numeric)))
 })
 
@@ -161,13 +171,16 @@ test_that("Exclude output class is same as input class", {
 test_that("Exclude messages are displayed properly", {
   suppressMessages(expect_message(
     exclude_duration(qualtrics_numeric, min_duration = 10, quiet = FALSE),
-    "took less time"))
+    "took less time"
+  ))
   suppressMessages(expect_message(
     exclude_duration(qualtrics_numeric, max_duration = 200, quiet = FALSE),
-    "took more time"))
+    "took more time"
+  ))
   suppressMessages(expect_message(
     exclude_duration(qualtrics_numeric, silent = FALSE),
-    "rows of short and/or long duration were excluded"))
+    "rows of short and/or long duration were excluded"
+  ))
   expect_message(
     exclude_duration(qualtrics_numeric, quiet = TRUE, silent = TRUE), NA
   )
@@ -175,12 +188,14 @@ test_that("Exclude messages are displayed properly", {
 
 test_that("Exclude output is printed or not", {
   expect_visible(
-    exclude_duration(qualtrics_numeric, quiet = TRUE, silent = TRUE
-    ))
+    exclude_duration(qualtrics_numeric, quiet = TRUE, silent = TRUE)
+  )
   expect_invisible(
-    exclude_duration(qualtrics_numeric, quiet = TRUE, print = FALSE,
-                     silent = TRUE
-    ))
+    exclude_duration(qualtrics_numeric,
+      quiet = TRUE, print = FALSE,
+      silent = TRUE
+    )
+  )
 })
 
 test_that("Excludes create data frames of correct size", {
