@@ -2,15 +2,17 @@
 
 test_that("Column names are renamed correctly", {
   suppressMessages(expect_true(names(mark_preview(qualtrics_fetch))[1] ==
-                                 "StartDate"))
+    "StartDate"))
   suppressMessages(expect_true(names(mark_preview(qualtrics_fetch,
-                                                  rename = FALSE))[1] ==
-                                 "StartDate"))
+    rename = FALSE
+  ))[1] ==
+    "StartDate"))
   suppressMessages(expect_true(names(mark_preview(qualtrics_numeric))[1] ==
-                                 "StartDate"))
+    "StartDate"))
   suppressMessages(expect_true(names(mark_preview(qualtrics_numeric,
-                                                  rename = FALSE))[1] ==
-                                 "StartDate"))
+    rename = FALSE
+  ))[1] ==
+    "StartDate"))
   suppressMessages(expect_message(mark_preview(qualtrics_numeric)))
 })
 
@@ -44,15 +46,17 @@ test_that("Marks create data frames of correct size", {
 
 test_that("Column names are renamed correctly", {
   suppressMessages(expect_true(names(check_preview(qualtrics_fetch))[1] ==
-                                 "StartDate"))
+    "StartDate"))
   suppressMessages(expect_true(names(check_preview(qualtrics_fetch,
-                                                   rename = FALSE))[1] ==
-                                 "StartDate"))
+    rename = FALSE
+  ))[1] ==
+    "StartDate"))
   suppressMessages(expect_true(names(check_preview(qualtrics_numeric))[1] ==
-                                 "StartDate"))
+    "StartDate"))
   suppressMessages(expect_true(names(check_preview(qualtrics_numeric,
-                                                   rename = FALSE))[1] ==
-                                 "StartDate"))
+    rename = FALSE
+  ))[1] ==
+    "StartDate"))
   suppressMessages(expect_message(check_preview(qualtrics_numeric)))
 })
 
@@ -75,8 +79,8 @@ test_that("Check messages are displayed properly", {
 test_that("Check output is printed properly", {
   expect_visible(check_preview(qualtrics_numeric, quiet = TRUE))
   expect_invisible(
-    check_preview(qualtrics_numeric, quiet = TRUE, print = FALSE
-    ))
+    check_preview(qualtrics_numeric, quiet = TRUE, print = FALSE)
+  )
 })
 
 test_that("Checks create data frames of correct size", {
@@ -101,15 +105,17 @@ test_that("Exclusion column moved to first column when keep = TRUE", {
 
 test_that("Column names are renamed correctly", {
   suppressMessages(expect_true(names(exclude_preview(qualtrics_fetch))[1] ==
-                                 "StartDate"))
+    "StartDate"))
   suppressMessages(expect_true(names(exclude_preview(qualtrics_fetch,
-                                                     rename = FALSE))[1] ==
-                                 "StartDate"))
+    rename = FALSE
+  ))[1] ==
+    "StartDate"))
   suppressMessages(expect_true(names(exclude_preview(qualtrics_numeric))[1] ==
-                                 "StartDate"))
+    "StartDate"))
   suppressMessages(expect_true(names(exclude_preview(qualtrics_numeric,
-                                                     rename = FALSE))[1] ==
-                                 "StartDate"))
+    rename = FALSE
+  ))[1] ==
+    "StartDate"))
   suppressMessages(expect_message(exclude_preview(qualtrics_numeric)))
 })
 
@@ -137,12 +143,14 @@ test_that("Exclude messages are displayed properly", {
 
 test_that("Exclude output is printed properly", {
   expect_visible(
-    exclude_preview(qualtrics_numeric, quiet = TRUE, silent = TRUE
-    ))
+    exclude_preview(qualtrics_numeric, quiet = TRUE, silent = TRUE)
+  )
   expect_invisible(
-    exclude_preview(qualtrics_numeric,quiet = TRUE, print = FALSE,
-                    silent = TRUE
-    ))
+    exclude_preview(qualtrics_numeric,
+      quiet = TRUE, print = FALSE,
+      silent = TRUE
+    )
+  )
 })
 
 test_that("Excludes create data frames of correct size", {
