@@ -2,15 +2,17 @@
 
 test_that("Column names are renamed correctly", {
   suppressMessages(expect_true(names(mark_progress(qualtrics_fetch))[1] ==
-                                 "StartDate"))
+    "StartDate"))
   suppressMessages(expect_true(names(mark_progress(qualtrics_fetch,
-                                                   rename = FALSE))[1] ==
-                                 "StartDate"))
+    rename = FALSE
+  ))[1] ==
+    "StartDate"))
   suppressMessages(expect_true(names(mark_progress(qualtrics_numeric))[1] ==
-                                 "StartDate"))
+    "StartDate"))
   suppressMessages(expect_true(names(mark_progress(qualtrics_numeric,
-                                                   rename = FALSE))[1] ==
-                                 "StartDate"))
+    rename = FALSE
+  ))[1] ==
+    "StartDate"))
   suppressMessages(expect_message(mark_progress(qualtrics_numeric)))
 })
 
@@ -33,8 +35,8 @@ test_that("Mark messages are displayed properly", {
 test_that("Mark output is printed properly", {
   expect_visible(mark_progress(qualtrics_numeric, quiet = TRUE))
   expect_invisible(
-    mark_progress(qualtrics_numeric, quiet = TRUE, print = FALSE
-    ))
+    mark_progress(qualtrics_numeric, quiet = TRUE, print = FALSE)
+  )
 })
 
 test_that("Marks create data frames of correct size", {
@@ -56,15 +58,17 @@ test_that("Marks create data frames of correct size", {
 
 test_that("Column names are renamed correctly", {
   suppressMessages(expect_true(names(check_progress(qualtrics_fetch))[1] ==
-                                 "StartDate"))
+    "StartDate"))
   suppressMessages(expect_true(names(check_progress(qualtrics_fetch,
-                                                    rename = FALSE))[1] ==
-                                 "StartDate"))
+    rename = FALSE
+  ))[1] ==
+    "StartDate"))
   suppressMessages(expect_true(names(check_progress(qualtrics_numeric))[1] ==
-                                 "StartDate"))
+    "StartDate"))
   suppressMessages(expect_true(names(check_progress(qualtrics_numeric,
-                                                    rename = FALSE))[1] ==
-                                 "StartDate"))
+    rename = FALSE
+  ))[1] ==
+    "StartDate"))
   suppressMessages(expect_message(check_progress(qualtrics_numeric)))
 })
 
@@ -87,8 +91,8 @@ test_that("Check messages are displayed properly", {
 test_that("Check output is printed properly", {
   expect_visible(check_progress(qualtrics_numeric, quiet = TRUE))
   expect_invisible(
-    check_progress(qualtrics_numeric, quiet = TRUE, print = FALSE
-    ))
+    check_progress(qualtrics_numeric, quiet = TRUE, print = FALSE)
+  )
 })
 
 test_that("Checks create data frames of correct size", {
@@ -123,15 +127,17 @@ test_that("Exclusion column moved to first column when keep = TRUE", {
 
 test_that("Column names are renamed correctly", {
   suppressMessages(expect_true(names(exclude_progress(qualtrics_fetch))[1] ==
-                                 "StartDate"))
+    "StartDate"))
   suppressMessages(expect_true(names(exclude_progress(qualtrics_fetch,
-                                                      rename = FALSE))[1] ==
-                                 "StartDate"))
+    rename = FALSE
+  ))[1] ==
+    "StartDate"))
   suppressMessages(expect_true(names(exclude_progress(qualtrics_numeric))[1] ==
-                                 "StartDate"))
+    "StartDate"))
   suppressMessages(expect_true(names(exclude_progress(qualtrics_numeric,
-                                                      rename = FALSE))[1] ==
-                                 "StartDate"))
+    rename = FALSE
+  ))[1] ==
+    "StartDate"))
   suppressMessages(expect_message(exclude_progress(qualtrics_numeric)))
 })
 
@@ -159,12 +165,14 @@ test_that("Exclude messages are displayed properly", {
 
 test_that("Exclude output is printed properly", {
   expect_visible(
-    exclude_progress(qualtrics_numeric, quiet = TRUE, silent = TRUE
-    ))
+    exclude_progress(qualtrics_numeric, quiet = TRUE, silent = TRUE)
+  )
   expect_invisible(
-    exclude_progress(qualtrics_numeric, quiet = TRUE, print = FALSE,
-                     silent = TRUE
-    ))
+    exclude_progress(qualtrics_numeric,
+      quiet = TRUE, print = FALSE,
+      silent = TRUE
+    )
+  )
 })
 
 test_that("Excludes create data frames of correct size", {
