@@ -2,14 +2,16 @@
 
 test_that("Column names are renamed correctly", {
   suppressMessages(expect_true(names(mark_resolution(qualtrics_fetch))[1] ==
-                                 "StartDate"))
+    "StartDate"))
   suppressMessages(expect_true(names(mark_resolution(qualtrics_numeric))[1] ==
-                                 "StartDate"))
+    "StartDate"))
   suppressMessages(expect_true(names(mark_resolution(qualtrics_numeric,
-                                                     rename = FALSE))[1] ==
-                                 "StartDate"))
+    rename = FALSE
+  ))[1] ==
+    "StartDate"))
   suppressMessages(expect_error(mark_resolution(qualtrics_fetch,
-                                                rename = FALSE)))
+    rename = FALSE
+  )))
   suppressMessages(expect_message(mark_resolution(qualtrics_numeric)))
 })
 
@@ -32,8 +34,8 @@ test_that("Mark messages are displayed properly", {
 test_that("Mark output is printed properly", {
   expect_visible(mark_resolution(qualtrics_numeric, quiet = TRUE))
   expect_invisible(
-    mark_resolution(qualtrics_numeric, quiet = TRUE, print = FALSE
-    ))
+    mark_resolution(qualtrics_numeric, quiet = TRUE, print = FALSE)
+  )
 })
 
 test_that("Marks create data frames of correct size", {
@@ -45,14 +47,14 @@ test_that("Marks create data frames of correct size", {
   ))
   suppressMessages(expect_true(
     nrow(mark_resolution(qualtrics_numeric,
-                         height_min = 800,
-                         width_min = 0
+      height_min = 800,
+      width_min = 0
     )) == 100
   ))
   suppressMessages(expect_true(
     ncol(mark_resolution(qualtrics_numeric,
-                         height_min = 800,
-                         width_min = 0
+      height_min = 800,
+      width_min = 0
     )) == 17
   ))
 })
@@ -61,14 +63,16 @@ test_that("Marks create data frames of correct size", {
 
 test_that("Column names are renamed correctly", {
   suppressMessages(expect_true(names(check_resolution(qualtrics_fetch))[1] ==
-                                 "StartDate"))
+    "StartDate"))
   suppressMessages(expect_true(names(check_resolution(qualtrics_numeric))[1] ==
-                                 "StartDate"))
+    "StartDate"))
   suppressMessages(expect_true(names(check_resolution(qualtrics_numeric,
-                                                      rename = FALSE))[1] ==
-                                 "StartDate"))
+    rename = FALSE
+  ))[1] ==
+    "StartDate"))
   suppressMessages(expect_error(check_resolution(qualtrics_fetch,
-                                                 rename = FALSE)))
+    rename = FALSE
+  )))
   suppressMessages(expect_message(check_resolution(qualtrics_numeric)))
 })
 
@@ -91,8 +95,8 @@ test_that("Check messages are displayed properly", {
 test_that("Check output is printed properly", {
   expect_visible(check_resolution(qualtrics_numeric, quiet = TRUE))
   expect_invisible(
-    check_resolution(qualtrics_numeric, quiet = TRUE, print = FALSE
-    ))
+    check_resolution(qualtrics_numeric, quiet = TRUE, print = FALSE)
+  )
 })
 
 test_that("Checks create data frames of correct size", {
@@ -101,21 +105,22 @@ test_that("Checks create data frames of correct size", {
   ))
   suppressMessages(expect_true(
     nrow(check_resolution(qualtrics_numeric,
-                          res_min = 0, width_min = 1000)) == 4
+      res_min = 0, width_min = 1000
+    )) == 4
   ))
   suppressMessages(expect_true(
     ncol(check_resolution(qualtrics_numeric)) == 16
   ))
   suppressMessages(expect_true(
     nrow(check_resolution(qualtrics_numeric,
-                          height_min = 800,
-                          width_min = 0
+      height_min = 800,
+      width_min = 0
     )) == 36
   ))
   suppressMessages(expect_true(
     ncol(check_resolution(qualtrics_numeric,
-                          height_min = 800,
-                          width_min = 0
+      height_min = 800,
+      width_min = 0
     )) == 16
   ))
   suppressMessages(expect_true(
@@ -123,7 +128,8 @@ test_that("Checks create data frames of correct size", {
   ))
   suppressMessages(expect_true(
     nrow(check_resolution(qualtrics_numeric,
-                          res_min = 0, width_min = 1000, keep = TRUE)) == 4
+      res_min = 0, width_min = 1000, keep = TRUE
+    )) == 4
   ))
   suppressMessages(expect_true(
     ncol(check_resolution(qualtrics_numeric, keep = TRUE)) == 17
@@ -141,14 +147,16 @@ test_that("Exclusion column moved to first column when keep = TRUE", {
 
 test_that("Column names are renamed correctly", {
   suppressMessages(expect_true(names(exclude_resolution(qualtrics_fetch))[1] ==
-                                 "StartDate"))
+    "StartDate"))
   suppressMessages(expect_true(names(exclude_resolution(qualtrics_numeric))[1]
-                               == "StartDate"))
+  == "StartDate"))
   suppressMessages(expect_true(names(exclude_resolution(qualtrics_numeric,
-                                                        rename = FALSE))[1] ==
-                                 "StartDate"))
+    rename = FALSE
+  ))[1] ==
+    "StartDate"))
   suppressMessages(expect_error(exclude_resolution(qualtrics_fetch,
-                                                   rename = FALSE)))
+    rename = FALSE
+  )))
   suppressMessages(expect_message(exclude_resolution(qualtrics_numeric)))
 })
 
@@ -176,18 +184,21 @@ test_that("Exclude messages are displayed properly", {
 
 test_that("Exclude output is printed properly", {
   expect_visible(
-    exclude_resolution(qualtrics_numeric, quiet = TRUE, silent = TRUE
-    ))
+    exclude_resolution(qualtrics_numeric, quiet = TRUE, silent = TRUE)
+  )
   expect_invisible(
-    exclude_resolution(qualtrics_numeric, quiet = TRUE, print = FALSE,
-                       silent = TRUE
-    ))
+    exclude_resolution(qualtrics_numeric,
+      quiet = TRUE, print = FALSE,
+      silent = TRUE
+    )
+  )
 })
 
 test_that("Excludes create data frames of correct size", {
   suppressMessages(
     expect_true(nrow(exclude_resolution(qualtrics_numeric,
-                                        res_min = 0, width_min = 1000)) == 96)
+      res_min = 0, width_min = 1000
+    )) == 96)
   )
   suppressMessages(
     expect_true(nrow(exclude_resolution(qualtrics_numeric)) == 97)
@@ -196,11 +207,11 @@ test_that("Excludes create data frames of correct size", {
     expect_true(ncol(exclude_resolution(qualtrics_numeric)) == 16)
   )
   suppressMessages(expect_true(nrow(exclude_resolution(qualtrics_numeric,
-                                                       height_min = 800,
-                                                       width_min = 0
+    height_min = 800,
+    width_min = 0
   )) == 64))
   suppressMessages(expect_true(ncol(exclude_resolution(qualtrics_numeric,
-                                                       height_min = 800,
-                                                       width_min = 0
+    height_min = 800,
+    width_min = 0
   )) == 16))
 })
